Class: ActiveRecord::Materialized::CacheTableSchema::IndexDefinition Private
- Inherits:
-
Data
- Object
- Data
- ActiveRecord::Materialized::CacheTableSchema::IndexDefinition
- Defined in:
- lib/activerecord/materialized/cache_table_schema.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
The partition-key index a cache table is built with: the GROUP BY / maintenance-key columns (unqualified to their cache-column names), unique when the key is the whole partition identity (a plain GROUP BY, one row per group). Incremental maintenance filters/deletes/re-selects by exactly these columns, so without this index every partition operation is a full cache scan.
Instance Attribute Summary collapse
-
#columns ⇒ Object
readonly
Returns the value of attribute columns.
-
#unique ⇒ Object
readonly
Returns the value of attribute unique.
Instance Attribute Details
#columns ⇒ Object (readonly)
Returns the value of attribute columns
34 35 36 |
# File 'lib/activerecord/materialized/cache_table_schema.rb', line 34 def columns @columns end |
#unique ⇒ Object (readonly)
Returns the value of attribute unique
34 35 36 |
# File 'lib/activerecord/materialized/cache_table_schema.rb', line 34 def unique @unique end |