Class: ActiveRecord::Materialized::PartitionRecord

Inherits:
Base
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/activerecord/materialized/partition_record.rb

Overview

One row per fresh partition of a cold view; presence means the partition is materialized and current, absence means it is not.

Class Method Summary collapse

Class Method Details

.table_nameObject



21
22
23
24
# File 'lib/activerecord/materialized/partition_record.rb', line 21

def self.table_name
  override = @table_name_override
  override.nil? ? ::ActiveRecord::Materialized.partition_table_name : override
end

.table_name=(name) ⇒ Object



16
17
18
# File 'lib/activerecord/materialized/partition_record.rb', line 16

def self.table_name=(name)
  @table_name_override = name
end